function [param,z] = exp_set_fixed_params(campaign)
% ----------------------------------------------------------------------
% DESCRIPTION
% 
% This function sets the FIXED parameters for each experimental
% configuration. In this case there is a single fixed parameter for each
% experimental configuration: the x-position of the measurement point. 
%
% Usually this function would contain the other fixed parameters of the
% physics-based model at that experimental configuration. 
%
% ----------------------------------------------------------------------
% NOMENCLATURE
%
% campaign          description of the experimental campaign    
% param{:}          structure containing the parameters for each experimental configuration: param{1} to param{M}. 
%
% ----------------------------------------------------------------------
% You can add your own campaigns below

switch campaign
    case {'9_points_equally_spaced'}
        param{1}.x = +0.4;
        param{2}.x = +0.3;
        param{3}.x = +0.2;
        param{4}.x = +0.1;
        param{5}.x =  0.0;
        param{6}.x = -0.1;
        param{7}.x = -0.2;
        param{8}.x = -0.3;
        param{9}.x = -0.4;
    case {'5_points_equally_spaced'}
        param{1}.x = +0.4;
        param{2}.x = +0.2;
        param{3}.x =  0.0;
        param{4}.x = -0.2;
        param{5}.x = -0.4;
    case 'MacKay_28_2'
        param{1}.x = -8.0;
        param{2}.x = -2.0;
        param{3}.x =  6.0;
    otherwise
        disp('CAMPAIGN NOT SPECIFIED IN exp_set_params.m')
end
