function [RGB_out] = gen_RGB(RGB_in)
% ---------------------------------------------------------------------------
% gen_RGB Library of colours in RGB format
%   RGB = gen_RGB returns a structure containing all colours
%
%   RGB = gen_RGB({'colourname') returns just the colour requested
%
%   RGB = gen_RGB('what') returns the names of possible colours
% 
%   RGB = gen_RGB('show') plots all available colours
% ---------------------------------------------------------------------------

% MPJ colours
RGB.dark_blue         = [000,062,116]/255;
RGB.blue              = [104,172,229]/255;
RGB.teal              = [145,185,164]/255;
RGB.orange            = [243,189,072]/255;
RGB.dark_orange       = [234,113,037]/255;
RGB.dark_red          = [144,028,059]/255;
% UCAM house colours https://www.cam.ac.uk/brand-resources/guidelines/typography-and-colour/rgb-and-hex-references
RGB.ucam_core_red     = [214,008,059]/255;
RGB.ucam_core_blue    = [000,114,207]/255;
RGB.ucam_core_orange  = [227,114,034]/255;
RGB.ucam_core_green   = [088,166,024]/255;
RGB.ucam_core_purple  = [142,037,141]/255;
RGB.ucam_core_teal    = [000,179,190]/255;
RGB.ucam_light_red    = [235,153,169]/255;
RGB.ucam_light_blue   = [106,173,228]/255;
RGB.ucam_light_orange = [243,189,072]/255;
RGB.ucam_light_green  = [168,180,000]/255;
RGB.ucam_light_purple = [181,147,155]/255;
RGB.ucam_light_teal   = [163,193,164]/255;
RGB.ucam_dark_red     = [144,028,059]/255;
RGB.ucam_dark_blue    = [000,062,114]/255;
RGB.ucam_dark_orange  = [200,078,000]/255;
RGB.ucam_dark_green   = [067,081,037]/255;
RGB.ucam_dark_purple  = [065,045,093]/255;
RGB.ucam_dark_teal    = [021,101,112]/255;

% Extract the fieldnames
RGB_fieldnames = fieldnames(RGB);

if nargin == 0
    % Return all colours
    RGB_out = RGB;
else
    if iscell(RGB_in)
        % Return a structure containing just the colours requested
        % NOT YET IMPLEMENTED
    else
        switch RGB_in
            case 'what'
                % return the names of all possible colours
                RGB_out = RGB_fieldnames;
            case 'show'
                % plot all available colours
                N = numel(RGB_fieldnames);
                figure; hold on
                for n = 1:N
                    plot([0,1],[n,n],'LineWidth',10,'Color',RGB.(RGB_fieldnames{n}));
                    han = text(   1.1 , n   ,RGB_fieldnames{n}); set(han,'FontSize',16,'Interpreter','none')
                end
                xlim([0,2])
                axis off
            otherwise
                RGB_out = RGB.(RGB_in);
        end
    end
end

end

% Other names for ucam colours
% RGB.Pantone199      = [214,008,059]/255;
% RGB.Pantone285      = [000,114,207]/255;
% RGB.Pantone158      = [227,114,034]/255;
% RGB.Pantone369      = [088,166,024]/255;
% RGB.Pantone513      = [142,037,141]/255;
% RGB.Pantone7466     = [000,179,190]/255;
% RGB.Pantone197      = [235,153,169]/255;
% RGB.Pantone284      = [106,173,228]/255;
% RGB.Pantone142      = [243,189,072]/255;
% RGB.Pantone583      = [168,180,000]/255;
% RGB.Pantone5215     = [181,147,155]/255;
% RGB.Pantone557      = [163,193,164]/255;
% RGB.Pantone1955     = [144,028,059]/255;
% RGB.Pantone541      = [000,062,114]/255;
% RGB.Pantone718      = [200,078,000]/255;
% RGB.Pantone574      = [067,081,037]/255;
% RGB.Pantone669      = [065,045,093]/255;
% RGB.Pantone5473     = [021,101,112]/255;
